hstrat.hstrat.stratum\_retention\_condemners.StratumRetentionCondemnerNominalResolution
=======================================================================================

.. currentmodule:: hstrat.hstrat.stratum_retention_condemners

.. autoclass:: StratumRetentionCondemnerNominalResolution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StratumRetentionCondemnerNominalResolution.CalcMrcaUncertaintyUpperBound
      ~StratumRetentionCondemnerNominalResolution.CalcNumStrataRetainedExact
      ~StratumRetentionCondemnerNominalResolution.CalcNumStrataRetainedUpperBound
      ~StratumRetentionCondemnerNominalResolution.CalcRankAtColumnIndex
      ~StratumRetentionCondemnerNominalResolution.__init__
   
   

   
   
   